@@ -13,3 +13,7 @@ class JSONWebTokenError(Exception):
 
 class PermissionDenied(JSONWebTokenError):
     default_message = _('You do not have permission to perform this action')
+
+
+class JSONWebTokenExpired(JSONWebTokenError):
+    default_message = _('Signature has expired')
